/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "qtmobility_contacts_python.h"

#include "qtmobility_qcontactlocalidfetchrequest_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcontactfilter.h>
#include <qcontactlocalidfetchrequest.h>
#include <qcontactmanager.h>
#include <qcontactsortorder.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;
using namespace QtMobility;

// Native ---------------------------------------------------------

QContactLocalIdFetchRequestWrapper::QContactLocalIdFetchRequestWrapper(QObject * parent) : QtMobility::QContactLocalIdFetchRequest(parent), m_metaObject(0) {
    // ... middle
}

void QContactLocalIdFetchRequestWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QContactLocalIdFetchRequestWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QContactLocalIdFetchRequestWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QContactLocalIdFetchRequestWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QContactLocalIdFetchRequestWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QContactLocalIdFetchRequest.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QContactLocalIdFetchRequestWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QContactLocalIdFetchRequest.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QContactLocalIdFetchRequestWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QContactLocalIdFetchRequestWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QtMobility::QContactLocalIdFetchRequest::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QContactLocalIdFetchRequestWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QtMobility::QContactLocalIdFetchRequest::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QContactLocalIdFetchRequestWrapper::~QContactLocalIdFetchRequestWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QContactLocalIdFetchRequest_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QContactLocalIdFetchRequest >()))
        return -1;

    QContactLocalIdFetchRequestWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QContactLocalIdFetchRequest", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QContactLocalIdFetchRequest(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QContactLocalIdFetchRequest(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QContactLocalIdFetchRequest(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactLocalIdFetchRequest_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "QtMobility.Contacts.QContactLocalIdFetchRequest(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QContactLocalIdFetchRequest(QObject*)
            cptr = new QContactLocalIdFetchRequestWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QContactLocalIdFetchRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QContactLocalIdFetchRequest_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQtMobility_QContactLocalIdFetchRequest_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Contacts.QContactLocalIdFetchRequest", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QContactLocalIdFetchRequestFunc_filter(PyObject* self)
{
    QtMobility::QContactLocalIdFetchRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactLocalIdFetchRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // filter()const
            QtMobility::QContactFilter cppResult = cppSelf->QtMobility::QContactLocalIdFetchRequest::filter();
            pyResult = Shiboken::Converter<QtMobility::QContactFilter >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QContactLocalIdFetchRequestFunc_ids(PyObject* self)
{
    QtMobility::QContactLocalIdFetchRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactLocalIdFetchRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ids()const
            QList<QtMobility::QContactLocalId > cppResult = cppSelf->QtMobility::QContactLocalIdFetchRequest::ids();
            pyResult = Shiboken::Converter<QList<QtMobility::QContactLocalId > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QContactLocalIdFetchRequestFunc_setFilter(PyObject* self, PyObject* arg)
{
    QtMobility::QContactLocalIdFetchRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactLocalIdFetchRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilter(QtMobility::QContactFilter)
    if (Shiboken::Converter<const QtMobility::QContactFilter & >::isConvertible(arg)) {
        overloadId = 0; // setFilter(QtMobility::QContactFilter)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactLocalIdFetchRequestFunc_setFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QtMobility::QContactFilter* cpp_arg0 = Shiboken::Converter<QtMobility::QContactFilter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFilter(QtMobility::QContactFilter)
            cppSelf->QtMobility::QContactLocalIdFetchRequest::setFilter(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactLocalIdFetchRequestFunc_setFilter_TypeError:
        const char* overloads[] = {"QtMobility.Contacts.QtMobility::QContactFilter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactLocalIdFetchRequest.setFilter", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactLocalIdFetchRequestFunc_setSorting(PyObject* self, PyObject* arg)
{
    QtMobility::QContactLocalIdFetchRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactLocalIdFetchRequest* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSorting(QList<QtMobility::QContactSortOrder>)
    if (Shiboken::Converter< QList<QtMobility::QContactSortOrder >  >::isConvertible(arg)) {
        overloadId = 0; // setSorting(QList<QtMobility::QContactSortOrder>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactLocalIdFetchRequestFunc_setSorting_TypeError;

    // Call function/method
    {
        {
            QList<QtMobility::QContactSortOrder > cpp_arg0 = Shiboken::Converter<QList<QtMobility::QContactSortOrder > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSorting(QList<QtMobility::QContactSortOrder>)
            cppSelf->QtMobility::QContactLocalIdFetchRequest::setSorting(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactLocalIdFetchRequestFunc_setSorting_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactLocalIdFetchRequest.setSorting", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactLocalIdFetchRequestFunc_sorting(PyObject* self)
{
    QtMobility::QContactLocalIdFetchRequest* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactLocalIdFetchRequest* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sorting()const
            QList<QtMobility::QContactSortOrder > cppResult = cppSelf->QtMobility::QContactLocalIdFetchRequest::sorting();
            pyResult = Shiboken::Converter<QList<QtMobility::QContactSortOrder > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQtMobility_QContactLocalIdFetchRequest_methods[] = {
    {"filter", (PyCFunction)SbkQtMobility_QContactLocalIdFetchRequestFunc_filter, METH_NOARGS},
    {"ids", (PyCFunction)SbkQtMobility_QContactLocalIdFetchRequestFunc_ids, METH_NOARGS},
    {"setFilter", (PyCFunction)SbkQtMobility_QContactLocalIdFetchRequestFunc_setFilter, METH_O},
    {"setSorting", (PyCFunction)SbkQtMobility_QContactLocalIdFetchRequestFunc_setSorting, METH_O},
    {"sorting", (PyCFunction)SbkQtMobility_QContactLocalIdFetchRequestFunc_sorting, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QContactLocalIdFetchRequest_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Contacts.QContactLocalIdFetchRequest",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QContactLocalIdFetchRequest_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QContactLocalIdFetchRequest_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QContactLocalIdFetchRequest >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QContactLocalIdFetchRequest*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQtMobility_QContactLocalIdFetchRequest_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QtMobility::QContactLocalIdFetchRequest*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQtMobility_QContactLocalIdFetchRequest_Type;
    return 0;
}


void init_QtMobility_QContactLocalIdFetchRequest(PyObject* module)
{
    SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTLOCALIDFETCHREQUEST_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QContactLocalIdFetchRequest_Type);

    SbkQtMobility_QContactLocalIdFetchRequest_Type.super.ht_type.tp_base = SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTABSTRACTREQUEST_IDX];
    // Fill type discovery information
    SbkQtMobility_QContactLocalIdFetchRequest_Type.type_discovery = &SbkQtMobility_QContactLocalIdFetchRequest_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTABSTRACTREQUEST_IDX]), &SbkQtMobility_QContactLocalIdFetchRequest_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QContactLocalIdFetchRequest_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QContactLocalIdFetchRequest_Type));
    PyModule_AddObject(module, "QContactLocalIdFetchRequest",
        ((PyObject*)&SbkQtMobility_QContactLocalIdFetchRequest_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactLocalIdFetchRequest >("QtMobility::QContactLocalIdFetchRequest*");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactLocalIdFetchRequest >(typeid(QtMobility::QContactLocalIdFetchRequest).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactLocalIdFetchRequest >(typeid(QContactLocalIdFetchRequestWrapper).name());
    PySide::initQtMetaType<QtMobility::QContactLocalIdFetchRequest* >();
}

