/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "qtmobility_contacts_python.h"

#include "qtmobility_qcontactsynctarget_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <qcontactdetail.h>
#include <qcontactsynctarget.h>

using namespace Shiboken;
using namespace QtMobility;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QContactSyncTarget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QContactSyncTarget >()))
        return -1;

    QtMobility::QContactSyncTarget* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QContactSyncTarget", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QContactSyncTarget(QtMobility::QContactSyncTarget)
    // 1: QContactSyncTarget()
    // 2: QContactSyncTarget(QtMobility::QContactDetail)
    if (numArgs == 0) {
        overloadId = 1; // QContactSyncTarget()
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactDetail & >::isConvertible(arg)) {
        overloadId = 2; // QContactSyncTarget(QtMobility::QContactDetail)
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactSyncTarget & >::isConvertible(arg)) {
        overloadId = 0; // QContactSyncTarget(QtMobility::QContactSyncTarget)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactSyncTarget_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QContactSyncTarget(QtMobility::QContactSyncTarget)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QtMobility::QContactSyncTarget > cpp_arg0_auto_ptr;
                QtMobility::QContactSyncTarget* cpp_arg0 = Shiboken::Converter<QtMobility::QContactSyncTarget* >::toCpp(arg);
                if (!Shiboken::Converter<QtMobility::QContactSyncTarget >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QtMobility::QContactSyncTarget >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QContactSyncTarget(QtMobility::QContactSyncTarget)
                cptr = new QtMobility::QContactSyncTarget(*cpp_arg0);
                }
                break;
            }
            case 1: // QContactSyncTarget()
            {

                if(!PyErr_Occurred()) {
                // QContactSyncTarget()
                cptr = new QtMobility::QContactSyncTarget();
                }
                break;
            }
            case 2: // QContactSyncTarget(QtMobility::QContactDetail)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QtMobility::QContactDetail* cpp_arg0 = Shiboken::Converter<QtMobility::QContactDetail* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QContactSyncTarget(QtMobility::QContactDetail)
                cptr = new QtMobility::QContactSyncTarget(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QContactSyncTarget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QContactSyncTarget_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQtMobility_QContactSyncTarget_Init_TypeError:
        const char* overloads[] = {"QtMobility.Contacts.QtMobility::QContactSyncTarget", "", "QtMobility.Contacts.QtMobility::QContactDetail", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Contacts.QContactSyncTarget", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QContactSyncTargetFunc_setSyncTarget(PyObject* self, PyObject* arg)
{
    QtMobility::QContactSyncTarget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactSyncTarget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSyncTarget(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setSyncTarget(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactSyncTargetFunc_setSyncTarget_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSyncTarget(QString)
            cppSelf->QtMobility::QContactSyncTarget::setSyncTarget(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactSyncTargetFunc_setSyncTarget_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactSyncTarget.setSyncTarget", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactSyncTargetFunc_syncTarget(PyObject* self)
{
    QtMobility::QContactSyncTarget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactSyncTarget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // syncTarget()const
            QString cppResult = cppSelf->QtMobility::QContactSyncTarget::syncTarget();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQtMobility_QContactSyncTarget_methods[] = {
    {"setSyncTarget", (PyCFunction)SbkQtMobility_QContactSyncTargetFunc_setSyncTarget, METH_O},
    {"syncTarget", (PyCFunction)SbkQtMobility_QContactSyncTargetFunc_syncTarget, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QContactSyncTarget_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Contacts.QContactSyncTarget",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QContactSyncTarget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QContactSyncTarget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QContactSyncTarget >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QContactSyncTarget",
    /*user_data*/           0
};
} //extern


void init_QtMobility_QContactSyncTarget(PyObject* module)
{
    SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTSYNCTARGET_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QContactSyncTarget_Type);

    SbkQtMobility_QContactSyncTarget_Type.super.ht_type.tp_base = SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTDETAIL_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QContactSyncTarget_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QContactSyncTarget_Type));
    PyModule_AddObject(module, "QContactSyncTarget",
        ((PyObject*)&SbkQtMobility_QContactSyncTarget_Type));

    PyDict_SetItemString(SbkQtMobility_QContactSyncTarget_Type.super.ht_type.tp_dict, "FieldSyncTarget", Shiboken::Converter<QString >::toPython(QtMobility::QContactSyncTarget::FieldSyncTarget));
    PyDict_SetItemString(SbkQtMobility_QContactSyncTarget_Type.super.ht_type.tp_dict, "DefinitionName", Shiboken::Converter<QString >::toPython(QtMobility::QContactSyncTarget::DefinitionName));

    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactSyncTarget >("QtMobility::QContactSyncTarget");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactSyncTarget >("QtMobility::QContactSyncTarget*");
    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactSyncTarget >(typeid(QtMobility::QContactSyncTarget).name());
    PySide::initQtMetaType<QtMobility::QContactSyncTarget >();
}

