/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "qtmobility_contacts_python.h"

#include "qtmobility_qcontacttag_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <qcontactdetail.h>
#include <qcontacttag.h>

using namespace Shiboken;
using namespace QtMobility;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QContactTag_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QContactTag >()))
        return -1;

    QtMobility::QContactTag* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QContactTag", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QContactTag(QtMobility::QContactTag)
    // 1: QContactTag()
    // 2: QContactTag(QtMobility::QContactDetail)
    if (numArgs == 0) {
        overloadId = 1; // QContactTag()
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactDetail & >::isConvertible(arg)) {
        overloadId = 2; // QContactTag(QtMobility::QContactDetail)
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactTag & >::isConvertible(arg)) {
        overloadId = 0; // QContactTag(QtMobility::QContactTag)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactTag_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QContactTag(QtMobility::QContactTag)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QtMobility::QContactTag > cpp_arg0_auto_ptr;
                QtMobility::QContactTag* cpp_arg0 = Shiboken::Converter<QtMobility::QContactTag* >::toCpp(arg);
                if (!Shiboken::Converter<QtMobility::QContactTag >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QtMobility::QContactTag >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QContactTag(QtMobility::QContactTag)
                cptr = new QtMobility::QContactTag(*cpp_arg0);
                }
                break;
            }
            case 1: // QContactTag()
            {

                if(!PyErr_Occurred()) {
                // QContactTag()
                cptr = new QtMobility::QContactTag();
                }
                break;
            }
            case 2: // QContactTag(QtMobility::QContactDetail)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QtMobility::QContactDetail* cpp_arg0 = Shiboken::Converter<QtMobility::QContactDetail* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QContactTag(QtMobility::QContactDetail)
                cptr = new QtMobility::QContactTag(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QContactTag >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QContactTag_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQtMobility_QContactTag_Init_TypeError:
        const char* overloads[] = {"QtMobility.Contacts.QtMobility::QContactTag", "", "QtMobility.Contacts.QtMobility::QContactDetail", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Contacts.QContactTag", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QContactTagFunc_setTag(PyObject* self, PyObject* arg)
{
    QtMobility::QContactTag* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactTag* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTag(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setTag(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactTagFunc_setTag_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTag(QString)
            cppSelf->QtMobility::QContactTag::setTag(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactTagFunc_setTag_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactTag.setTag", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactTagFunc_tag(PyObject* self)
{
    QtMobility::QContactTag* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactTag* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tag()const
            QString cppResult = cppSelf->QtMobility::QContactTag::tag();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQtMobility_QContactTag_methods[] = {
    {"setTag", (PyCFunction)SbkQtMobility_QContactTagFunc_setTag, METH_O},
    {"tag", (PyCFunction)SbkQtMobility_QContactTagFunc_tag, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QContactTag_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Contacts.QContactTag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QContactTag_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QContactTag_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QContactTag >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QContactTag",
    /*user_data*/           0
};
} //extern


void init_QtMobility_QContactTag(PyObject* module)
{
    SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTTAG_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QContactTag_Type);

    SbkQtMobility_QContactTag_Type.super.ht_type.tp_base = SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTDETAIL_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QContactTag_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QContactTag_Type));
    PyModule_AddObject(module, "QContactTag",
        ((PyObject*)&SbkQtMobility_QContactTag_Type));

    PyDict_SetItemString(SbkQtMobility_QContactTag_Type.super.ht_type.tp_dict, "FieldTag", Shiboken::Converter<QString >::toPython(QtMobility::QContactTag::FieldTag));
    PyDict_SetItemString(SbkQtMobility_QContactTag_Type.super.ht_type.tp_dict, "DefinitionName", Shiboken::Converter<QString >::toPython(QtMobility::QContactTag::DefinitionName));

    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactTag >("QtMobility::QContactTag");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactTag >("QtMobility::QContactTag*");
    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactTag >(typeid(QtMobility::QContactTag).name());
    PySide::initQtMetaType<QtMobility::QContactTag >();
}

