/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "qtmobility_contacts_python.h"

#include "qtmobility_qcontacturl_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <qcontactdetail.h>
#include <qcontacturl.h>

using namespace Shiboken;
using namespace QtMobility;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QContactUrl_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QContactUrl >()))
        return -1;

    QtMobility::QContactUrl* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QContactUrl", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QContactUrl(QtMobility::QContactUrl)
    // 1: QContactUrl()
    // 2: QContactUrl(QtMobility::QContactDetail)
    if (numArgs == 0) {
        overloadId = 1; // QContactUrl()
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactDetail & >::isConvertible(arg)) {
        overloadId = 2; // QContactUrl(QtMobility::QContactDetail)
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QContactUrl & >::isConvertible(arg)) {
        overloadId = 0; // QContactUrl(QtMobility::QContactUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactUrl_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QContactUrl(QtMobility::QContactUrl)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QtMobility::QContactUrl > cpp_arg0_auto_ptr;
                QtMobility::QContactUrl* cpp_arg0 = Shiboken::Converter<QtMobility::QContactUrl* >::toCpp(arg);
                if (!Shiboken::Converter<QtMobility::QContactUrl >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QtMobility::QContactUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QContactUrl(QtMobility::QContactUrl)
                cptr = new QtMobility::QContactUrl(*cpp_arg0);
                }
                break;
            }
            case 1: // QContactUrl()
            {

                if(!PyErr_Occurred()) {
                // QContactUrl()
                cptr = new QtMobility::QContactUrl();
                }
                break;
            }
            case 2: // QContactUrl(QtMobility::QContactDetail)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QtMobility::QContactDetail* cpp_arg0 = Shiboken::Converter<QtMobility::QContactDetail* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QContactUrl(QtMobility::QContactDetail)
                cptr = new QtMobility::QContactUrl(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QContactUrl >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QContactUrl_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQtMobility_QContactUrl_Init_TypeError:
        const char* overloads[] = {"QtMobility.Contacts.QtMobility::QContactUrl", "", "QtMobility.Contacts.QtMobility::QContactDetail", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Contacts.QContactUrl", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QContactUrlFunc_setSubType(PyObject* self, PyObject* arg)
{
    QtMobility::QContactUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSubType(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setSubType(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactUrlFunc_setSubType_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSubType(QString)
            cppSelf->QtMobility::QContactUrl::setSubType(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactUrlFunc_setSubType_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactUrl.setSubType", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactUrlFunc_setUrl(PyObject* self, PyObject* arg)
{
    QtMobility::QContactUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QContactUrlFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUrl(QString)
            cppSelf->QtMobility::QContactUrl::setUrl(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QContactUrlFunc_setUrl_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Contacts.QContactUrl.setUrl", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QContactUrlFunc_subType(PyObject* self)
{
    QtMobility::QContactUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // subType()const
            QString cppResult = cppSelf->QtMobility::QContactUrl::subType();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QContactUrlFunc_url(PyObject* self)
{
    QtMobility::QContactUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QContactUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QString cppResult = cppSelf->QtMobility::QContactUrl::url();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQtMobility_QContactUrl_methods[] = {
    {"setSubType", (PyCFunction)SbkQtMobility_QContactUrlFunc_setSubType, METH_O},
    {"setUrl", (PyCFunction)SbkQtMobility_QContactUrlFunc_setUrl, METH_O},
    {"subType", (PyCFunction)SbkQtMobility_QContactUrlFunc_subType, METH_NOARGS},
    {"url", (PyCFunction)SbkQtMobility_QContactUrlFunc_url, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QContactUrl_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Contacts.QContactUrl",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QContactUrl_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QContactUrl_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QContactUrl >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QContactUrl",
    /*user_data*/           0
};
} //extern


void init_QtMobility_QContactUrl(PyObject* module)
{
    SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTURL_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QContactUrl_Type);

    SbkQtMobility_QContactUrl_Type.super.ht_type.tp_base = SbkQtMobility_ContactsTypes[SBK_QTMOBILITY_QCONTACTDETAIL_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QContactUrl_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QContactUrl_Type));
    PyModule_AddObject(module, "QContactUrl",
        ((PyObject*)&SbkQtMobility_QContactUrl_Type));

    PyDict_SetItemString(SbkQtMobility_QContactUrl_Type.super.ht_type.tp_dict, "SubTypeHomePage", Shiboken::Converter<QString >::toPython(QtMobility::QContactUrl::SubTypeHomePage));
    PyDict_SetItemString(SbkQtMobility_QContactUrl_Type.super.ht_type.tp_dict, "SubTypeFavourite", Shiboken::Converter<QString >::toPython(QtMobility::QContactUrl::SubTypeFavourite));
    PyDict_SetItemString(SbkQtMobility_QContactUrl_Type.super.ht_type.tp_dict, "FieldSubType", Shiboken::Converter<QString >::toPython(QtMobility::QContactUrl::FieldSubType));
    PyDict_SetItemString(SbkQtMobility_QContactUrl_Type.super.ht_type.tp_dict, "FieldUrl", Shiboken::Converter<QString >::toPython(QtMobility::QContactUrl::FieldUrl));
    PyDict_SetItemString(SbkQtMobility_QContactUrl_Type.super.ht_type.tp_dict, "DefinitionName", Shiboken::Converter<QString >::toPython(QtMobility::QContactUrl::DefinitionName));

    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactUrl >("QtMobility::QContactUrl");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QContactUrl >("QtMobility::QContactUrl*");
    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QContactUrl >(typeid(QtMobility::QContactUrl).name());
    PySide::initQtMetaType<QtMobility::QContactUrl >();
}

