/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "qtmobility_messaging_python.h"

#include "qtmobility_qmessageid_wrapper.h"

// Extra includes
#include <qmessageid.h>

using namespace Shiboken;
using namespace QtMobility;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QMessageId_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QMessageId >()))
        return -1;

    QtMobility::QMessageId* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMessageId", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QMessageId()
    // 1: QMessageId(QString)
    // 2: QMessageId(QtMobility::QMessageId)
    if (numArgs == 0) {
        overloadId = 0; // QMessageId()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // QMessageId(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QtMobility::QMessageId & >::isConvertible(arg)) {
        overloadId = 2; // QMessageId(QtMobility::QMessageId)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QMessageId_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMessageId()
            {

                if(!PyErr_Occurred()) {
                // QMessageId()
                cptr = new QtMobility::QMessageId();
                }
                break;
            }
            case 1: // QMessageId(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QMessageId(QString)
                cptr = new QtMobility::QMessageId(cpp_arg0);
                }
                break;
            }
            case 2: // QMessageId(QtMobility::QMessageId)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QtMobility::QMessageId > cpp_arg0_auto_ptr;
                QtMobility::QMessageId* cpp_arg0 = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(arg);
                if (!Shiboken::Converter<QtMobility::QMessageId >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QtMobility::QMessageId >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QMessageId(QtMobility::QMessageId)
                cptr = new QtMobility::QMessageId(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QMessageId >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QMessageId_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQtMobility_QMessageId_Init_TypeError:
        const char* overloads[] = {"", "QString", "QtMobility.Messaging.QtMobility::QMessageId", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Messaging.QMessageId", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QMessageIdFunc_isValid(PyObject* self)
{
    QtMobility::QMessageId* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QtMobility::QMessageId::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QMessageIdFunc_toString(PyObject* self)
{
    QtMobility::QMessageId* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toString()const
            QString cppResult = cppSelf->QtMobility::QMessageId::toString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQtMobility_QMessageId_methods[] = {
    {"isValid", (PyCFunction)SbkQtMobility_QMessageIdFunc_isValid, METH_NOARGS},
    {"toString", (PyCFunction)SbkQtMobility_QMessageIdFunc_toString, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQtMobility_QMessageId_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QtMobility::QMessageId& cpp_self = *Shiboken::Converter<QtMobility::QMessageId* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QtMobility::QMessageId & >::isConvertible(other)) {
                // operator!=(const QtMobility::QMessageId & other) const
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QtMobility::QMessageId  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QtMobility::QMessageId >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QtMobility::QMessageId > cpp_other_auto_ptr;
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                if (!Shiboken::Converter<QtMobility::QMessageId >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QtMobility::QMessageId >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQtMobility_QMessageId_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QtMobility::QMessageId & >::isConvertible(other)) {
                // operator<(const QtMobility::QMessageId & other) const
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QtMobility::QMessageId  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else if (Shiboken::Converter<QtMobility::QMessageId >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QtMobility::QMessageId > cpp_other_auto_ptr;
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                if (!Shiboken::Converter<QtMobility::QMessageId >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QtMobility::QMessageId >(cpp_other);
                result = (cpp_self < (*cpp_other));
            } else goto SbkQtMobility_QMessageId_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QtMobility::QMessageId & >::isConvertible(other)) {
                // operator==(const QtMobility::QMessageId & other) const
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QtMobility::QMessageId  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QtMobility::QMessageId >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QtMobility::QMessageId > cpp_other_auto_ptr;
                QtMobility::QMessageId* cpp_other = Shiboken::Converter<QtMobility::QMessageId* >::toCpp(other);
                if (!Shiboken::Converter<QtMobility::QMessageId >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QtMobility::QMessageId >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQtMobility_QMessageId_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQtMobility_QMessageId_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQtMobility_QMessageId_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter<QtMobility::QMessageId >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QMessageId_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Messaging.QMessageId",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQtMobility_QMessageId_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQtMobility_QMessageId_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QMessageId_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QMessageId_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QMessageId >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QMessageId",
    /*user_data*/           0
};
} //extern


void init_QtMobility_QMessageId(PyObject* module)
{
    SbkQtMobility_MessagingTypes[SBK_QTMOBILITY_QMESSAGEID_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QMessageId_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QMessageId_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QMessageId_Type));
    PyModule_AddObject(module, "QMessageId",
        ((PyObject*)&SbkQtMobility_QMessageId_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QMessageId >("QtMobility::QMessageId");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QMessageId >("QtMobility::QMessageId*");
    Shiboken::TypeResolver::createValueTypeResolver<QtMobility::QMessageId >(typeid(QtMobility::QMessageId).name());
    PySide::initQtMetaType<QtMobility::QMessageId >();
}

