/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "qtmobility_versit_python.h"

#include "qtmobility_qversitwriter_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtextcodec.h>
#include <qthread.h>
#include <qversitdocument.h>

using namespace Shiboken;
using namespace QtMobility;

// Native ---------------------------------------------------------

QVersitWriterWrapper::QVersitWriterWrapper() : QtMobility::QVersitWriter(), m_metaObject(0) {
    // ... middle
}

QVersitWriterWrapper::QVersitWriterWrapper(QByteArray * outputBytes) : QtMobility::QVersitWriter(outputBytes), m_metaObject(0) {
    // ... middle
}

QVersitWriterWrapper::QVersitWriterWrapper(QIODevice * outputDevice) : QtMobility::QVersitWriter(outputDevice), m_metaObject(0) {
    // ... middle
}

void QVersitWriterWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QVersitWriterWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QVersitWriterWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QVersitWriterWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QVersitWriterWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QVersitWriter.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QVersitWriterWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QVersitWriter.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QVersitWriterWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QVersitWriterWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QtMobility::QVersitWriter::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QVersitWriterWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QtMobility::QVersitWriter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QVersitWriterWrapper::~QVersitWriterWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQtMobility_QVersitWriter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QtMobility::QVersitWriter >()))
        return -1;

    QVersitWriterWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QVersitWriter", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QVersitWriter()
    // 1: QVersitWriter(QByteArray*)
    // 2: QVersitWriter(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QVersitWriter()
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 2; // QVersitWriter(QIODevice*)
    } else if (numArgs == 1 && Shiboken::Converter<QByteArray * >::isConvertible(arg)) {
        overloadId = 1; // QVersitWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QVersitWriter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVersitWriter()
            {

                if(!PyErr_Occurred()) {
                // QVersitWriter()
                cptr = new QVersitWriterWrapper();
                }
                break;
            }
            case 1: // QVersitWriter(QByteArray*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QVersitWriter(QByteArray*)
                cptr = new QVersitWriterWrapper(cpp_arg0);
                }
                break;
            }
            case 2: // QVersitWriter(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QVersitWriter(QIODevice*)
                cptr = new QVersitWriterWrapper(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QtMobility::QVersitWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQtMobility_QVersitWriter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQtMobility_QVersitWriter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QtMobility.Versit.QVersitWriter", overloads);
        return -1;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_cancel(PyObject* self)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cancel()
            cppSelf->QtMobility::QVersitWriter::cancel();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_defaultCodec(PyObject* self)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultCodec()const
            QTextCodec * cppResult = cppSelf->QtMobility::QVersitWriter::defaultCodec();
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_device(PyObject* self)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QtMobility::QVersitWriter::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_error(PyObject* self)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QtMobility::QVersitWriter::Error cppResult = cppSelf->QtMobility::QVersitWriter::error();
            pyResult = Shiboken::Converter<QtMobility::QVersitWriter::Error >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_setDefaultCodec(PyObject* self, PyObject* arg)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultCodec(QTextCodec*)
    if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setDefaultCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QVersitWriterFunc_setDefaultCodec_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultCodec(QTextCodec*)
            cppSelf->QtMobility::QVersitWriter::setDefaultCodec(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QVersitWriterFunc_setDefaultCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Versit.QVersitWriter.setDefaultCodec", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_setDevice(PyObject* self, PyObject* arg)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QVersitWriterFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QtMobility::QVersitWriter::setDevice(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtMobility_QVersitWriterFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Versit.QVersitWriter.setDevice", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_startWriting(PyObject* self, PyObject* arg)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startWriting(QList<QtMobility::QVersitDocument>)
    if (Shiboken::Converter< QList<QtMobility::QVersitDocument >  >::isConvertible(arg)) {
        overloadId = 0; // startWriting(QList<QtMobility::QVersitDocument>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QVersitWriterFunc_startWriting_TypeError;

    // Call function/method
    {
        {
            QList<QtMobility::QVersitDocument > cpp_arg0 = Shiboken::Converter<QList<QtMobility::QVersitDocument > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startWriting(QList<QtMobility::QVersitDocument>)
            bool cppResult = cppSelf->QtMobility::QVersitWriter::startWriting(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtMobility_QVersitWriterFunc_startWriting_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Versit.QVersitWriter.startWriting", overloads);
        return 0;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_state(PyObject* self)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QtMobility::QVersitWriter::State cppResult = cppSelf->QtMobility::QVersitWriter::state();
            pyResult = Shiboken::Converter<QtMobility::QVersitWriter::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtMobility_QVersitWriterFunc_waitForFinished(PyObject* self, PyObject* args, PyObject* kwds)
{
    QtMobility::QVersitWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QtMobility::QVersitWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msec" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "QtMobility.Versit.QVersitWriter.waitForFinished(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "QtMobility.Versit.QVersitWriter.waitForFinished(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForFinished", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForFinished(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForFinished(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForFinished(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtMobility_QVersitWriterFunc_waitForFinished_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msec");
                if (value) {
                    if (arg)
                        errorArgName = "msec";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "QtMobility.Versit.QVersitWriter.waitForFinished(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // waitForFinished(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QtMobility::QVersitWriter::waitForFinished(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtMobility_QVersitWriterFunc_waitForFinished_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QtMobility.Versit.QVersitWriter.waitForFinished", overloads);
        return 0;
}

static PyMethodDef SbkQtMobility_QVersitWriter_methods[] = {
    {"cancel", (PyCFunction)SbkQtMobility_QVersitWriterFunc_cancel, METH_NOARGS},
    {"defaultCodec", (PyCFunction)SbkQtMobility_QVersitWriterFunc_defaultCodec, METH_NOARGS},
    {"device", (PyCFunction)SbkQtMobility_QVersitWriterFunc_device, METH_NOARGS},
    {"error", (PyCFunction)SbkQtMobility_QVersitWriterFunc_error, METH_NOARGS},
    {"setDefaultCodec", (PyCFunction)SbkQtMobility_QVersitWriterFunc_setDefaultCodec, METH_O},
    {"setDevice", (PyCFunction)SbkQtMobility_QVersitWriterFunc_setDevice, METH_O},
    {"startWriting", (PyCFunction)SbkQtMobility_QVersitWriterFunc_startWriting, METH_O},
    {"state", (PyCFunction)SbkQtMobility_QVersitWriterFunc_state, METH_NOARGS},
    {"waitForFinished", (PyCFunction)SbkQtMobility_QVersitWriterFunc_waitForFinished, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQtMobility_QVersitWriter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMobility.Versit.QVersitWriter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQtMobility_QVersitWriter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQtMobility_QVersitWriter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QtMobility::QVersitWriter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QtMobility::QVersitWriter*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQtMobility_QVersitWriter_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QtMobility::QVersitWriter*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQtMobility_QVersitWriter_Type;
    return 0;
}

static PyGetSetDef SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Error",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkQtMobility_Versit_QtMobility_QVersitWriter_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkQtMobility_Versit_QtMobility_QVersitWriter_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQtMobility_Versit_QtMobility_QVersitWriter_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkQtMobility_Versit_QtMobility_QVersitWriter_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkQtMobility_Versit_QtMobility_QVersitWriter_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QtMobility_QVersitWriter(PyObject* module)
{
    SbkQtMobility_VersitTypes[SBK_QTMOBILITY_QVERSITWRITER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQtMobility_QVersitWriter_Type);

    SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQtMobility_QVersitWriter_Type.type_discovery = &SbkQtMobility_QVersitWriter_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQtMobility_QVersitWriter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_QVersitWriter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQtMobility_QVersitWriter_Type));
    PyModule_AddObject(module, "QVersitWriter",
        ((PyObject*)&SbkQtMobility_QVersitWriter_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Error
    SbkQtMobility_VersitTypes[SBK_QTMOBILITY_QVERSITWRITER_ERROR_IDX] = &SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type;
    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type) < 0)
        return;
    Py_INCREF(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type);
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type,
        (long) QtMobility::QVersitWriter::NoError, "NoError");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type,
        (long) QtMobility::QVersitWriter::UnspecifiedError, "UnspecifiedError");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "UnspecifiedError", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type.tp_dict,
        "UnspecifiedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type,
        (long) QtMobility::QVersitWriter::IOError, "IOError");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "IOError", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type.tp_dict,
        "IOError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type,
        (long) QtMobility::QVersitWriter::OutOfMemoryError, "OutOfMemoryError");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "OutOfMemoryError", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type.tp_dict,
        "OutOfMemoryError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type,
        (long) QtMobility::QVersitWriter::NotReadyError, "NotReadyError");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "NotReadyError", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_Error_Type.tp_dict,
        "NotReadyError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QtMobility::QVersitWriter::Error");

    // init enum class: State
    SbkQtMobility_VersitTypes[SBK_QTMOBILITY_QVERSITWRITER_STATE_IDX] = &SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type) < 0)
        return;
    Py_INCREF(&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type);
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type,
        (long) QtMobility::QVersitWriter::InactiveState, "InactiveState");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "InactiveState", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type.tp_dict,
        "InactiveState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type,
        (long) QtMobility::QVersitWriter::ActiveState, "ActiveState");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "ActiveState", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type.tp_dict,
        "ActiveState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type,
        (long) QtMobility::QVersitWriter::CanceledState, "CanceledState");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "CanceledState", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type.tp_dict,
        "CanceledState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type,
        (long) QtMobility::QVersitWriter::FinishedState, "FinishedState");
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict,
        "FinishedState", enum_item);
    PyDict_SetItemString(SbkQtMobility_Versit_QtMobility_QVersitWriter_State_Type.tp_dict,
        "FinishedState", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QtMobility::QVersitWriter::State");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("stateChanged", "QtMobility::QVersitWriter::State", NULL);
    PyDict_SetItemString(SbkQtMobility_QVersitWriter_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QVersitWriter >("QtMobility::QVersitWriter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QVersitWriter >(typeid(QtMobility::QVersitWriter).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QtMobility::QVersitWriter >(typeid(QVersitWriterWrapper).name());
    PySide::initQtMetaType<QtMobility::QVersitWriter* >();
}

