/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "qtmobility_versit_python.h"


// Global functions ------------------------------------------------------------

static PyMethodDef Versit_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QtMobility_QVersitProperty(PyObject* module);
void init_QtMobility_QVersitContactImporter(PyObject* module);
void init_QtMobility_QVersitContactImporterPropertyHandler(PyObject* module);
void init_QtMobility_QVersitContactExporter(PyObject* module);
void init_QtMobility_QVersitContactExporterDetailHandler(PyObject* module);
void init_QtMobility_QVersitResourceHandler(PyObject* module);
void init_QtMobility_QVersitDefaultResourceHandler(PyObject* module);
void init_QtMobility_QVersitDocument(PyObject* module);
void init_QtMobility_QVersitWriter(PyObject* module);
void init_QtMobility_QVersitReader(PyObject* module);

PyTypeObject** SbkQtMobility_VersitTypes;

PyTypeObject** SbkQtMobility_ContactsTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initVersit()
{
    if (!Shiboken::importModule("QtMobility.Contacts", &SbkQtMobility_ContactsTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import QtMobility.Contacts");
        return;
    }

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    Shiboken::initShiboken();
    PyObject* module = Py_InitModule("Versit", Versit_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_Versit_IDX_COUNT];
    SbkQtMobility_VersitTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QtMobility_QVersitProperty(module);
    init_QtMobility_QVersitContactImporter(module);
    init_QtMobility_QVersitContactImporterPropertyHandler(module);
    init_QtMobility_QVersitContactExporter(module);
    init_QtMobility_QVersitContactExporterDetailHandler(module);
    init_QtMobility_QVersitResourceHandler(module);
    init_QtMobility_QVersitDefaultResourceHandler(module);
    init_QtMobility_QVersitDocument(module);
    init_QtMobility_QVersitWriter(module);
    init_QtMobility_QVersitReader(module);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module Versit");
    }
}

